@@ -215,6 +215,9 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
     two_archives = 0
     one_archive = 0
 
+    session = boto3.Session()
+    s3 = session.resource("s3")
+
     for sample_item in samples:
         result = json.loads(sample_item)["data-point"]
 
@@ -241,15 +244,7 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
                 md5_doi = hashlib.md5(doi["DOI"].lower().encode())
                 key = f"{ANNOTATION_PATH}/works/{md5_doi}/{ANNOTATION_FILENAME}"
 
-                session = boto3.Session()
-                s3 = session.resource("s3")
-
-                push_json_to_s3(
-                    s3=s3,
-                    json_obj=preservation_statuses,
-                    bucket=ANNOTATION_BUCKET,
-                    path=key,
-                )
+                preserved_json = {}
 
                 # increment the sample count
                 overall_status["sample-count"] += 1
@@ -269,6 +264,22 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
                         # increment total preservation instances count
                         overall_status["preservation-instances"] += 1
 
+                        # log this for DOI-level annotation
+                        if done:
+                            preserved_json[key] = "preserved"
+                        else:
+                            preserved_json[key] = "preserved (in progress)"
+
+                    else:
+                        preserved_json[key] = "unpreserved"
+
+                push_json_to_s3(
+                    s3=s3,
+                    json_obj=preserved_json,
+                    bucket=ANNOTATION_BUCKET,
+                    path=key,
+                )
+
                 # preserved_count refers to the number of works with at
                 # least one preservation
                 if has_preservation:
